@@ -18,16 +18,15 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#include "rt_defines.h"
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
 //#include "omp.h"
-#include "CVfast_types.h"
+#include "MAVEfast_types.h"
 
 /* Function Declarations */
-extern void MAVEfast(emxArray_real_T *x, const emxArray_real_T *y, const
-                     emxArray_char_T *method, emxArray_real_T *BB1D,
-                     emxArray_real_T *ky);
+extern void MAVEfast(emxArray_real_T *x, const emxArray_real_T *y,
+                     emxArray_char_T *method, emxArray_real_T *which_dim,
+                     emxArray_real_T *BB1D, emxArray_real_T *ky);
 
 #endif
 
