@@ -18,15 +18,12 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#include "rt_defines.h"
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
 //#include "omp.h"
-#include "CVfast_types.h"
+#include "MAVEfast_types.h"
 
 /* Function Declarations */
-extern void b_combine_vector_elements(const emxArray_real_T *x, emxArray_real_T *
-  y);
 extern void combine_vector_elements(const emxArray_real_T *x, emxArray_real_T *y);
 
 #endif
